==> blesta-5.10.2.zip: blesta/language/el_gr/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Πελάτης Ξέχασα το όνομα χρήστη μου';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Πελάτης Επαναφορά του κωδικού μου';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Διαχειριστής Επαναφορά του κωδικού μου';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Σύνδεση πελάτη';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Σύνδεση διαχειριστή';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'reCaptcha Κοινόχρηστο κλειδί';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'Κλειδί ιστότοπου reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Εσωτερικό Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Κανένα';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Ενεργοποιημένες φόρμες';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Πάροχος Captcha';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Ανθρώπινη επαλήθευση';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Αναζήτηση πακέτων';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Αναζήτηση υπηρεσιών';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Αναζήτηση συναλλαγών';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Αναζήτηση τιμών';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Αναζήτηση τιμολογίων';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Αναζήτηση πελατών';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Έξυπνη αναζήτηση';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Παρουσιάστε στους πελάτες τη δυνατότητα επιλογής opt-in/opt-out του μάρκετινγκ ηλεκτρονικού ταχυδρομείου';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Μάρκετινγκ';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Επεξεργασία τύπου επαφής';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Χρήση Ορισμός γλώσσας';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Όνομα';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Επεξεργασία τύπου επαφής';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Επεξεργασία τύπου επαφής';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Χρήση Ορισμός γλώσσας';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Όνομα';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Επιλέξτε αυτό το πλαίσιο μόνο εάν έχετε προσθέσει έναν ορισμό γλώσσας για αυτόν τον τύπο επαφής στο προσαρμοσμένο αρχείο γλώσσας.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Δεν υπάρχουν τύποι επαφών.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Η διαγραφή αυτού του τύπου επαφής θα προκαλέσει την τοποθέτηση όλων των επαφών που αντιστοιχούν σε αυτόν τον τύπο στον προεπιλεγμένο τύπο "Χρέωση". Είστε σίγουροι ότι θέλετε να διαγράψετε αυτόν τον τύπο επαφής;';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Διαγραφή';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Επεξεργασία';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Όχι';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Ναι';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Επιλογές';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Χρήσεις Γλώσσα Ορισμός';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Όνομα';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Τύποι επικοινωνίας';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Τύποι επαφών';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Ενημέρωση κωδικού πρόσβασης';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Έχω αποθηκεύσει αυτή τη συνθηματική φράση σε ασφαλές μέρος';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Επιβεβαίωση της φράσης πρόσβασης του ιδιωτικού κλειδιού';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Νέα φράση πρόσβασης ιδιωτικού κλειδιού';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Τρέχουσα φράση πρόσβασης ιδιωτικού κλειδιού';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Κρυπτογράφηση';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Έχει οριστεί μια συνθηματική φράση. Απαιτείται να ομαδοποιήσετε χειροκίνητα τις πληρωμές με τη συνθηματική σας φράση. Η αλλαγή της συνθηματικής σας φράσης σε κενή συνθηματική φράση θα καταργήσει αυτή την απαίτηση.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Ο ορισμός μιας φράσης πρόσβασης θα αποτρέψει την αυτόματη επεξεργασία των τοπικά αποθηκευμένων λογαριασμών πληρωμών. Θα χρειαστεί να ομαδοποιήσετε χειροκίνητα τις πληρωμές εισάγοντας τη συνθηματική σας φράση. Για περισσότερες πληροφορίες σχετικά με αυτή τη λειτουργία συμβουλευτείτε το εγχειρίδιο.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Κρυπτογράφηση';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Σίγουρα θέλετε να απεγκαταστήσετε τη γλώσσα %1$s; Αυτή η γλώσσα θα απεγκατασταθεί και όλα τα πρότυπα email σε αυτή τη γλώσσα θα διαγραφούν οριστικά.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Είστε σίγουροι ότι θέλετε να εγκαταστήσετε τη γλώσσα %1$s;';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Απεγκατάσταση του';
$lang['AdminCompanyGeneral.international.option_install'] = 'Εγκαταστήστε το';
$lang['AdminCompanyGeneral.international.text_options'] = 'Επιλογές';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Γλώσσα';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Διεθνοποίηση';
$lang['AdminCompanyGeneral.international.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Διεθνοποίηση';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Υπάρχει ένα πρόγραμμα μετάφρασης από το πλήθος στο translate.blesta.com. Μπορείτε να συνεισφέρετε και να κατεβάσετε γλωσσικές μεταφράσεις από εκεί. Για να εγκαταστήσετε, αποσυμπιέστε τα περιεχόμενα του αρχείου στον κατάλογο εγκατάστασης του Blesta. Στη συνέχεια, ανανεώστε αυτή τη σελίδα και κάντε κλικ στο σύνδεσμο Install (Εγκατάσταση).';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Προεπιλεγμένη χώρα';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Μορφή ημερομηνίας ώρας';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Μορφή ημερομηνίας';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Χρονοζώνη';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Δευτέρα';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Κυριακή';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Ημερολόγιο Ημέρα έναρξης';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Ο πελάτης μπορεί να ορίσει Γλώσσα';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Προεπιλεγμένη γλώσσα';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Εντοπισμός';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Εντοπισμός';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Αυτό είναι το captcha που χρησιμοποιείται από προεπιλογή, το Internal Captcha απαιτεί την επέκταση GD.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Αυτή είναι η χώρα που επιλέγεται από προεπιλογή στις σχετικές φόρμες.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Ορίζει τη μορφή ημερομηνίας και ώρας. Αυτή η μορφή χρησιμοποιείται κατά την εμφάνιση ημερομηνίας και ώρας. Ανατρέξτε στο εγχειρίδιο php για τις διαθέσιμες επιλογές.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Ορίζει τη μορφή ημερομηνίας. Αυτή η μορφή χρησιμοποιείται κατά την εμφάνιση μιας ημερομηνίας. Ανατρέξτε στο εγχειρίδιο php για τις διαθέσιμες επιλογές.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Αυτή είναι η ζώνη ώρας του συστήματος στην οποία θα διαμορφωθούν οι μετατροπές ημερομηνίας και ώρας.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Ορίστε την εβδομαδιαία ημέρα έναρξης του ημερολογίου.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Όταν επιλεγεί, οι πελάτες μπορούν να επιλέξουν τη δική τους γλώσσα για χρήση από τις διαθέσιμες στο σύστημα.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Η προεπιλεγμένη γλώσσα που χρησιμοποιείται από το σύστημα. Για να προσθέσετε περισσότερες γλώσσες ανατρέξτε στην ενότητα Ρυθμίσεις διεθνοποίησης.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Οι ρυθμίσεις ανθρώπινης επαλήθευσης ενημερώθηκαν επιτυχώς.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Οι ρυθμίσεις της Έξυπνης αναζήτησης ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Οι ρυθμίσεις μάρκετινγκ ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Η γλώσσα %1$s απεγκαταστάθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'Η γλώσσα %1$s εγκαταστάθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Ο τύπος επαφής "%1$s" διαγράφηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Ο τύπος επαφής "%1$s" ενημερώθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Ο τύπος επαφής "%1$s" προστέθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Οι ρυθμίσεις κρυπτογράφησης ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Οι ρυθμίσεις εντοπισμού ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'Η επέκταση GD απαιτείται για τη δημιουργία του εσωτερικού captcha.';

==> blesta-5.11.4.zip: blesta/language/el_gr/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Πελάτης Ξέχασα το όνομα χρήστη μου';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Πελάτης Επαναφορά του κωδικού μου';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Διαχειριστής Επαναφορά του κωδικού μου';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Σύνδεση πελάτη';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Σύνδεση διαχειριστή';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'reCaptcha Κοινόχρηστο κλειδί';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'Κλειδί ιστότοπου reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Εσωτερικό Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Κανένα';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Ενεργοποιημένες φόρμες';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Πάροχος Captcha';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Ανθρώπινη επαλήθευση';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Αναζήτηση πακέτων';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Αναζήτηση υπηρεσιών';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Αναζήτηση συναλλαγών';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Αναζήτηση τιμών';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Αναζήτηση τιμολογίων';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Αναζήτηση πελατών';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Έξυπνη αναζήτηση';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Παρουσιάστε στους πελάτες τη δυνατότητα επιλογής opt-in/opt-out του μάρκετινγκ ηλεκτρονικού ταχυδρομείου';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Μάρκετινγκ';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Επεξεργασία τύπου επαφής';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Χρήση Ορισμός γλώσσας';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Όνομα';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Επεξεργασία τύπου επαφής';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Επεξεργασία τύπου επαφής';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Χρήση Ορισμός γλώσσας';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Όνομα';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Επιλέξτε αυτό το πλαίσιο μόνο εάν έχετε προσθέσει έναν ορισμό γλώσσας για αυτόν τον τύπο επαφής στο προσαρμοσμένο αρχείο γλώσσας.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Δεν υπάρχουν τύποι επαφών.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Η διαγραφή αυτού του τύπου επαφής θα προκαλέσει την τοποθέτηση όλων των επαφών που αντιστοιχούν σε αυτόν τον τύπο στον προεπιλεγμένο τύπο "Χρέωση". Είστε σίγουροι ότι θέλετε να διαγράψετε αυτόν τον τύπο επαφής;';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Διαγραφή';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'Επεξεργασία';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Όχι';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Ναι';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Επιλογές';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Χρήσεις Γλώσσα Ορισμός';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Όνομα';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Τύποι επικοινωνίας';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Δημιουργία τύπου επαφής';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Τύποι επαφών';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Ενημέρωση κωδικού πρόσβασης';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Έχω αποθηκεύσει αυτή τη συνθηματική φράση σε ασφαλές μέρος';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Επιβεβαίωση της φράσης πρόσβασης του ιδιωτικού κλειδιού';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Νέα φράση πρόσβασης ιδιωτικού κλειδιού';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Τρέχουσα φράση πρόσβασης ιδιωτικού κλειδιού';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Κρυπτογράφηση';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Έχει οριστεί μια συνθηματική φράση. Απαιτείται να ομαδοποιήσετε χειροκίνητα τις πληρωμές με τη συνθηματική σας φράση. Η αλλαγή της συνθηματικής σας φράσης σε κενή συνθηματική φράση θα καταργήσει αυτή την απαίτηση.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Ο ορισμός μιας φράσης πρόσβασης θα αποτρέψει την αυτόματη επεξεργασία των τοπικά αποθηκευμένων λογαριασμών πληρωμών. Θα χρειαστεί να ομαδοποιήσετε χειροκίνητα τις πληρωμές εισάγοντας τη συνθηματική σας φράση. Για περισσότερες πληροφορίες σχετικά με αυτή τη λειτουργία συμβουλευτείτε το εγχειρίδιο.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Κρυπτογράφηση';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Σίγουρα θέλετε να απεγκαταστήσετε τη γλώσσα %1$s; Αυτή η γλώσσα θα απεγκατασταθεί και όλα τα πρότυπα email σε αυτή τη γλώσσα θα διαγραφούν οριστικά.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Είστε σίγουροι ότι θέλετε να εγκαταστήσετε τη γλώσσα %1$s;';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Απεγκατάσταση του';
$lang['AdminCompanyGeneral.international.option_install'] = 'Εγκαταστήστε το';
$lang['AdminCompanyGeneral.international.text_options'] = 'Επιλογές';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Γλώσσα';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Διεθνοποίηση';
$lang['AdminCompanyGeneral.international.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Διεθνοποίηση';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Υπάρχει ένα πρόγραμμα μετάφρασης από το πλήθος στο translate.blesta.com. Μπορείτε να συνεισφέρετε και να κατεβάσετε γλωσσικές μεταφράσεις από εκεί. Για να εγκαταστήσετε, αποσυμπιέστε τα περιεχόμενα του αρχείου στον κατάλογο εγκατάστασης του Blesta. Στη συνέχεια, ανανεώστε αυτή τη σελίδα και κάντε κλικ στο σύνδεσμο Install (Εγκατάσταση).';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Ενημέρωση ρυθμίσεων';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Προεπιλεγμένη χώρα';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Μορφή ημερομηνίας ώρας';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Μορφή ημερομηνίας';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Χρονοζώνη';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Δευτέρα';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Κυριακή';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Ημερολόγιο Ημέρα έναρξης';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Ο πελάτης μπορεί να ορίσει Γλώσσα';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Προεπιλεγμένη γλώσσα';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Εντοπισμός';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Ρυθμίσεις > Εταιρεία > Γενικά > Εντοπισμός';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Αυτό είναι το captcha που χρησιμοποιείται από προεπιλογή, το Internal Captcha απαιτεί την επέκταση GD.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Αυτή είναι η χώρα που επιλέγεται από προεπιλογή στις σχετικές φόρμες.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Ορίζει τη μορφή ημερομηνίας και ώρας. Αυτή η μορφή χρησιμοποιείται κατά την εμφάνιση ημερομηνίας και ώρας. Ανατρέξτε στο εγχειρίδιο php για τις διαθέσιμες επιλογές.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Ορίζει τη μορφή ημερομηνίας. Αυτή η μορφή χρησιμοποιείται κατά την εμφάνιση μιας ημερομηνίας. Ανατρέξτε στο εγχειρίδιο php για τις διαθέσιμες επιλογές.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Αυτή είναι η ζώνη ώρας του συστήματος στην οποία θα διαμορφωθούν οι μετατροπές ημερομηνίας και ώρας.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Ορίστε την εβδομαδιαία ημέρα έναρξης του ημερολογίου.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Όταν επιλεγεί, οι πελάτες μπορούν να επιλέξουν τη δική τους γλώσσα για χρήση από τις διαθέσιμες στο σύστημα.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Η προεπιλεγμένη γλώσσα που χρησιμοποιείται από το σύστημα. Για να προσθέσετε περισσότερες γλώσσες ανατρέξτε στην ενότητα Ρυθμίσεις διεθνοποίησης.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Οι ρυθμίσεις ανθρώπινης επαλήθευσης ενημερώθηκαν επιτυχώς.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Οι ρυθμίσεις της Έξυπνης αναζήτησης ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Οι ρυθμίσεις μάρκετινγκ ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Η γλώσσα %1$s απεγκαταστάθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'Η γλώσσα %1$s εγκαταστάθηκε επιτυχώς. Θυμηθείτε να ενημερώσετε τα μηνύματα ηλεκτρονικού ταχυδρομείου, τα πακέτα και τις ομάδες πακέτων με περιεχόμενο για τη νέα γλώσσα.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Ο τύπος επαφής "%1$s" διαγράφηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Ο τύπος επαφής "%1$s" ενημερώθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Ο τύπος επαφής "%1$s" προστέθηκε επιτυχώς.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Οι ρυθμίσεις κρυπτογράφησης ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Οι ρυθμίσεις εντοπισμού ενημερώθηκαν με επιτυχία.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'Η επέκταση GD απαιτείται για τη δημιουργία του εσωτερικού captcha.';
